@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# :copyright: (c) 2020 by Pavlo Dmytrenko.
+# :copyright: (c) 2021 by Pavlo Dmytrenko.
 # :license: MIT, see LICENSE for more details.
 
 """
@@ -41,6 +41,7 @@ COLOR_ATTRS = COLOR_MAP.keys()
 # Get spinner names:
 # $ < yaspin/data/spinners.json | jq '. | keys'
 SPINNER_ATTRS = [
+    "aesthetic",
     "arc",
     "arrow",
     "arrow2",
@@ -69,6 +70,7 @@ SPINNER_ATTRS = [
     "dots6",
     "dots7",
     "dots8",
+    "dots8Bit",
     "dots9",
     "dqpb",
     "earth",
@@ -81,6 +83,7 @@ SPINNER_ATTRS = [
     "layer",
     "line",
     "line2",
+    "material",
     "monkey",
     "moon",
     "noise",
